From 807b36e8edef2c70145d394422251e02d0a2d534 Mon Sep 17 00:00:00 2001
From: lpw <812862340@qq.com>
Date: Thu, 16 Jul 2026 09:29:44 +0800
Subject: [PATCH] 提交版本 4.13.0
---
WAAdmobImpl/GoogleMobileAds.xcframework/ios-arm64/GoogleMobileAds.framework/Headers/GADRewardedInterstitialAd.h | 36 +++++++++++++++++++++++++++++-------
1 files changed, 29 insertions(+), 7 deletions(-)
diff --git a/WAAdmobImpl/GoogleMobileAds.xcframework/ios-arm64/GoogleMobileAds.framework/Headers/GADRewardedInterstitialAd.h b/WAAdmobImpl/GoogleMobileAds.xcframework/ios-arm64/GoogleMobileAds.framework/Headers/GADRewardedInterstitialAd.h
index da8cdec..51231a1 100644
--- a/WAAdmobImpl/GoogleMobileAds.xcframework/ios-arm64/GoogleMobileAds.framework/Headers/GADRewardedInterstitialAd.h
+++ b/WAAdmobImpl/GoogleMobileAds.xcframework/ios-arm64/GoogleMobileAds.framework/Headers/GADRewardedInterstitialAd.h
@@ -26,6 +26,7 @@
/// A rewarded interstitial ad. Rewarded Interstitial ads are full screen ads that can be presented
/// without user-opt in and allow you to reward the user with in-app items.
+NS_SWIFT_NAME(RewardedInterstitialAd)
@interface GADRewardedInterstitialAd : NSObject <GADAdMetadataProvider, GADFullScreenPresentingAd>
/// The ad unit ID.
@@ -48,6 +49,10 @@
/// Called when the ad is estimated to have earned money. Available for allowlisted accounts only.
@property(nonatomic, nullable, copy) GADPaidEventHandler paidEventHandler;
+/// An identifier for a placement in reporting. This property must be set prior to presenting the
+/// ad.
+@property(nonatomic, readwrite) int64_t placementID;
+
/// Loads a rewarded interstitial ad.
///
/// @param adUnitID An ad unit ID created in the AdMob or Ad Manager UI.
@@ -55,14 +60,30 @@
/// @param completionHandler A handler to execute when the load operation finishes or times out.
+ (void)loadWithAdUnitID:(nonnull NSString *)adUnitID
request:(nullable GADRequest *)request
- completionHandler:(nonnull GADRewardedInterstitialAdLoadCompletionHandler)completionHandler;
+ completionHandler:(nonnull GADRewardedInterstitialAdLoadCompletionHandler)completionHandler
+ NS_SWIFT_NAME(load(with:request:completionHandler:))NS_SWIFT_SENDING;
-/// Returns whether the rewarded interstitial ad can be presented from the provided root view
-/// controller. Sets the error out parameter if the ad can't be presented. Must be called on the
-/// main thread. If rootViewController is nil, uses the top view controller of the application's
-/// main window.
+/// Loads a rewarded interstitial ad.
+///
+/// @param adResponseString A server-to-server ad response string.
+/// @param completionHandler A handler to execute when the load operation finishes or times out.
++ (void)loadWithAdResponseString:(nonnull NSString *)adResponseString
+ completionHandler:
+ (nonnull GADRewardedInterstitialAdLoadCompletionHandler)completionHandler
+ NS_SWIFT_NAME(load(with:completionHandler:))NS_SWIFT_SENDING;
+
+/// Indicates whether the rewarded interstitial ad can be presented from the provided root view
+/// controller. Must be called on the main thread.
+///
+/// - Parameters:
+/// - rootViewController: The root view controller to present the ad from. If `rootViewController`
+/// is `nil`, uses the top view controller of the application's main window.
+/// - error: Sets the error out parameter if the ad can't be presented.
+/// - Returns: `YES` if the rewarded interstitial ad can be presented from the provided root view
+/// controller, `NO` otherwise.
- (BOOL)canPresentFromRootViewController:(nullable UIViewController *)rootViewController
- error:(NSError *_Nullable __autoreleasing *_Nullable)error;
+ error:(NSError *_Nullable __autoreleasing *_Nullable)error
+ NS_SWIFT_NAME(canPresent(from:)) NS_SWIFT_UI_ACTOR;
/// Presents the rewarded interstitial ad. Must be called on the main thread.
///
@@ -71,6 +92,7 @@
/// @param userDidEarnRewardHandler A handler to execute when the user earns a reward. adReward
/// contains the reward information.
- (void)presentFromRootViewController:(nullable UIViewController *)viewController
- userDidEarnRewardHandler:(nonnull GADUserDidEarnRewardHandler)userDidEarnRewardHandler;
+ userDidEarnRewardHandler:(nonnull GADUserDidEarnRewardHandler)userDidEarnRewardHandler
+ NS_SWIFT_NAME(present(from:userDidEarnRewardHandler:)) NS_SWIFT_UI_ACTOR;
@end
--
Gitblit v1.8.0